Gammu Zarządzanie wszystkimi telefonami
=======================================

Gammu jest biblioteką i linią komend narzędzia dla telefonów
komórkowych. Jest udostępniany na licencji GNU GPL w wersji 2.

Został on zainicjowany przez Marcina Wiącka i innych ludzi. Oryginalny kod
był oparty na Gnokii <http://www.gnokii.org> i później mygnokii
<http://www.mwiacek.com>. Gammu był (do wersji 0.58) z nazwą MyGnokii2.

Obecnie projekt jest prowadzony przez Michal Cihar <michal@cihar.com> z
pomocą wielu użytkowników.

.. image:: https://travis-ci.org/gammu/gammu.svg?branch=master
    :alt: Build status :target: https://travis-ci.org/gammu/gammu

.. image:: https://hosted.weblate.org/widgets/gammu-status-badge.png
    :alt: Translation status :target:
    https://hosted.weblate.org/engage/gammu/?utm_source=widget

.. image:: https://scan.coverity.com/projects/2890/badge.svg?flat=1
    :alt: Coverity scan :target: https://scan.coverity.com/projects/2890

Więcej informacji
=================

Możesz znaleźć więcej informacji na temat <http://wammu.eu/gammu/>.

Istnieje również podręcznik Gammu dostępny w docs/manual. Możesz budować
wersję HTML za pomocą zrobić manual-html, który jest na:
<http://wammu.eu/docs/manual/>.


Opinie i raporty o błędach
==========================

Wszelkie uwagi są mile widziane, patrz <http://wammu.eu/support/> po
informację jak skontaktować się z programistami.


Wsparcie programistów
=====================

Można docenić pracę programistów na <http://wammu.eu/donate/>.
